@@ -146,7 +146,7 @@ void gnc_account_renumber_prefix_changed_cb (GtkEditable *editable, RenumberDial
 void gnc_account_renumber_interval_changed_cb (GtkSpinButton *spinbutton, RenumberDialog *data);
 void gnc_account_renumber_response_cb (GtkDialog *dialog, gint response, RenumberDialog *data);
 
-void gnc_account_window_destroy_cb (GtkObject *object, gpointer data);
+void gnc_account_window_destroy_cb (GtkWidget *object, gpointer data);
 void opening_equity_cb (GtkWidget *w, gpointer data);
 void gnc_account_name_changed_cb(GtkWidget *widget, gpointer data);
 void gnc_account_color_default_cb(GtkWidget *widget, gpointer data);
@@ -188,7 +188,7 @@ gnc_account_commodity_from_type (AccountWindow * aw, gboolean update)
     if (aw->type == ACCT_TYPE_TRADING)
         new_mode = DIAG_COMM_ALL;
     else if ((aw->type == ACCT_TYPE_STOCK) || (aw->type == ACCT_TYPE_MUTUAL))
-        new_mode = DIAG_COMM_NON_CURRENCY;
+        new_mode = DIAG_COMM_NON_CURRENCY_SELECT;
     else
         new_mode = DIAG_COMM_CURRENCY;
 
@@ -666,7 +666,7 @@ verify_children_compatible (AccountWindow *aw)
         gint size;
         PangoFontDescription *font_desc;
 
-        size = pango_font_description_get_size (label->style->font_desc);
+        size = pango_font_description_get_size (gtk_widget_get_style (label)->font_desc);
         font_desc = pango_font_description_new ();
         pango_font_description_set_weight (font_desc, PANGO_WEIGHT_BOLD);
         pango_font_description_set_size (font_desc, size * PANGO_SCALE_LARGE);
@@ -695,16 +695,16 @@ verify_children_compatible (AccountWindow *aw)
 
     gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
+    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), hbox,
                         TRUE, TRUE, 0);
 
     /* spacings */
     gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-    gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
+    gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 14);
     gtk_container_set_border_width (
-        GTK_CONTAINER (GTK_DIALOG (dialog)->action_area), 5);
-    gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->action_area), 6);
+        GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (dialog))), 5);
+    gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (dialog))), 6);
 
     gtk_widget_show_all (hbox);
 
@@ -970,7 +970,7 @@ gnc_account_window_response_cb (GtkDialog *dialog,
 }
 
 void
-gnc_account_window_destroy_cb (GtkObject *object, gpointer data)
+gnc_account_window_destroy_cb (GtkWidget *object, gpointer data)
 {
     AccountWindow *aw = data;
     Account *account;
@@ -1308,6 +1308,7 @@ gnc_account_window_create(AccountWindow *aw)
     GtkWidget *label;
     GtkBuilder  *builder;
     GtkTreeSelection *selection;
+    const gchar *tt = _("This Account contains Transactions.\nChanging this option is not possible.");
 
     ENTER("aw %p, modal %d", aw, aw->modal);
     builder = gtk_builder_new();
@@ -1338,8 +1339,21 @@ gnc_account_window_create(AccountWindow *aw)
                          gnc_commodity_edit_get_string,
                          gnc_commodity_edit_new_select,
                          &aw->commodity_mode);
-    gtk_box_pack_start(GTK_BOX(box), aw->commodity_edit, TRUE, TRUE, 0);
-    gtk_widget_show (aw->commodity_edit);
+
+    // If the account has transactions, prevent changes by displaying a label and tooltip
+    if (xaccAccountCountSplits (aw_get_account (aw), FALSE) > 0)
+    {
+        const gchar *sec_name = gnc_commodity_get_printname (xaccAccountGetCommodity(aw_get_account (aw)));
+        GtkWidget *label = gtk_label_new (sec_name);
+        gtk_widget_set_tooltip_text (label, tt);
+        gtk_box_pack_start (GTK_BOX(box), label, FALSE, FALSE, 0);
+        gtk_widget_show (label);
+    }
+    else
+    {
+        gtk_box_pack_start(GTK_BOX(box), aw->commodity_edit, TRUE, TRUE, 0);
+        gtk_widget_show (aw->commodity_edit);
+    }
 
     label = GTK_WIDGET(gtk_builder_get_object (builder, "security_label"));
     gnc_general_select_make_mnemonic_target (GNC_GENERAL_SELECT(aw->commodity_edit), label);
@@ -1373,7 +1387,7 @@ gnc_account_window_create(AccountWindow *aw)
     gtk_label_set_mnemonic_widget (GTK_LABEL(label), amount);
 
     box = GTK_WIDGET(gtk_builder_get_object (builder, "opening_balance_date_box"));
-    date_edit = gnc_date_edit_new (gnc_time (NULL), 1, 1);
+    date_edit = gnc_date_edit_new (gnc_time (NULL), 0, 0);
     aw->opening_balance_date_edit = date_edit;
     gtk_box_pack_start(GTK_BOX(box), date_edit, TRUE, TRUE, 0);
     gtk_widget_show (date_edit);
@@ -1401,6 +1415,22 @@ gnc_account_window_create(AccountWindow *aw)
     aw->type_view = GTK_WIDGET(gtk_builder_get_object (builder, "type_view"));
     gnc_account_type_view_create (aw);
 
+    // If the account has transactions, prevent changes by displaying a label and tooltip
+    if (xaccAccountCountSplits (aw_get_account (aw), FALSE) > 0)
+    {
+        GNCAccountType atype = xaccAccountGetType (aw_get_account (aw));
+        GtkWidget *label = gtk_label_new (xaccAccountGetTypeStr (atype));
+        GtkWidget *vbox = GTK_WIDGET(gtk_builder_get_object (builder, "type_vbox"));
+        GtkWidget *parent_widget = gtk_widget_get_parent (GTK_WIDGET(aw->type_view));
+
+        g_object_ref (G_OBJECT(aw->type_view));
+        gtk_container_remove (GTK_CONTAINER(vbox), parent_widget);
+        gtk_widget_set_tooltip_text (label, tt);
+        gtk_box_pack_start (GTK_BOX(vbox), label, FALSE, FALSE, 0);
+        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+        gtk_widget_show (label);
+    }
+
     gnc_restore_window_size (GNC_PREFS_GROUP, GTK_WINDOW(aw->dialog));
 
     gtk_widget_grab_focus(GTK_WIDGET(aw->name_entry));
