@@ -125,6 +125,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_DOUBLE_LEDGER_NUM_ACTN);
@@ -134,6 +135,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, TNUM_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SINGLE_JOURNAL);
@@ -154,6 +156,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_DOUBLE_JOURNAL_NUM_ACTN);
@@ -163,6 +166,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, TNUM_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SPLIT);
@@ -209,6 +213,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         copy_cursor_row (layout, curs, curs_last, 0);
 
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 3);
         gnc_table_layout_set_cell (layout, curs, MEMO_CELL, 1, 4);
 
@@ -217,6 +222,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         copy_cursor_row (layout, curs, curs_last, 0);
 
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, TNUM_CELL,  1, 3);
         gnc_table_layout_set_cell (layout, curs, MEMO_CELL, 1, 4);
 
@@ -246,6 +252,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         copy_cursor_row (layout, curs, curs_last, 0);
 
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, TNUM_CELL,  1, 3);
         gnc_table_layout_set_cell (layout, curs, MEMO_CELL, 1, 4);
 
@@ -297,6 +304,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_DOUBLE_LEDGER_NUM_ACTN);
@@ -306,6 +314,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SINGLE_JOURNAL);
@@ -331,6 +340,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_DOUBLE_JOURNAL_NUM_ACTN);
@@ -339,6 +349,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SPLIT);
@@ -390,6 +401,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_DOUBLE_LEDGER_NUM_ACTN);
@@ -399,6 +411,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, TNUM_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SINGLE_JOURNAL);
@@ -419,6 +432,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_DOUBLE_JOURNAL_NUM_ACTN);
@@ -428,6 +442,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, TNUM_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SPLIT);
@@ -469,6 +484,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, ACTN_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_DOUBLE_LEDGER_NUM_ACTN);
@@ -478,6 +494,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, TNUM_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SINGLE_JOURNAL);
@@ -497,6 +514,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
 
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_DOUBLE_JOURNAL_NUM_ACTN);
@@ -506,6 +524,7 @@ gnc_split_register_set_cells (SplitRegister *reg, TableLayout *layout)
         gnc_table_layout_set_cell (layout, curs, TNUM_CELL,  1, 1);
         gnc_table_layout_set_cell (layout, curs, NOTES_CELL, 1, 2);
         gnc_table_layout_set_cell (layout, curs, VNOTES_CELL, 1, 3);
+        gnc_table_layout_set_cell (layout, curs, ASSOC_CELL,  1, 4);
 
         curs = gnc_table_layout_get_cursor (layout,
                                             CURSOR_SPLIT);
@@ -673,6 +692,14 @@ gnc_split_register_layout_add_cells (SplitRegister *reg,
                            FALSE,
                            FALSE);
 
+    gnc_register_add_cell (layout,
+                           ASSOC_CELL,
+                           RECN_CELL_TYPE_NAME,
+                           N_("Associate:A") + 10,
+                           CELL_ALIGN_CENTER,
+                           FALSE,
+                           FALSE);
+
     gnc_register_add_cell (layout,
                            BALN_CELL,
                            PRICE_CELL_TYPE_NAME,
@@ -783,7 +810,7 @@ gnc_split_register_layout_add_cells (SplitRegister *reg,
                            TYPE_CELL,
                            RECN_CELL_TYPE_NAME,
                            N_("Type:T") + 5,
-                           CELL_ALIGN_LEFT,
+                           CELL_ALIGN_CENTER,
                            FALSE,
                            FALSE);
 
